searchData={"items":[{"type":"module","title":"Glasgow","doc":"An Elixir logger handler for sending logs to [`Grafana Loki`](https://github.com/grafana/loki).","ref":"Glasgow.html"},{"type":"module","title":"Installation - Glasgow","doc":"The package can be installed by adding `glasgow` to your list of dependencies in `mix.exs`:\r\n\r\n```elixir\r\ndef deps do\r\n[\r\n  {:glasgow, \"~> 0.1.2\"}\r\n]\r\nend\r\n```","ref":"Glasgow.html#module-installation"},{"type":"module","title":"Configuration - Glasgow","doc":"Example of a basic configuration for `config.exs` or `runtime.exs`:\r\n\r\n```elixir\r\nconfig :my_app, :logger, [\r\n{:handler, :glasgow, Glasgow,\r\n %{\r\n   config: %{\r\n     level: :info,\r\n     url: System.get_env(\"URL\", \"http://localhost:3100\"),\r\n     labels: [\r\n       {\"service_name\", \"service_1\"},\r\n       {\"env\", \"env_1\"}\r\n     ]\r\n   },\r\n   formatter: Logger.Formatter.new()\r\n }}\r\n]\r\n```\r\n\r\nOnce defined, the handler can be explicitly attached with `add_handlers/1`.\r\n\r\nFor example, in your `Application.start/2`:\r\n```elixir\r\n@impl true\r\ndef start(_type, _args) do\r\n  ...\r\n\r\n  :ok = Logger.add_handlers(:my_app)\r\n\r\n  ...\r\n\r\n  Supervisor.start_link(children, opts)\r\nend\r\n```\r\n\r\n#### Advanced Configuration\r\nElixir `Logger` handlers can be configured with [`filters`](https://hexdocs.pm/logger/Logger.html#module-filtering) and `metadata` to provide control and context.\r\n\r\n```elixir\r\nconfig :my_app, :logger, [\r\n{:handler, :glasgow, Glasgow,\r\n %{\r\n   config: %{\r\n     level: :info,\r\n     url: System.get_env(\"URL\", \"http://localhost:3100\"),\r\n     labels: [\r\n       {\"service_name\", \"service_1\"},\r\n       {\"env\", \"env_1\"}\r\n     ],\r\n     metadata: [:my_metadata_key]\r\n   },\r\n   formatter: Logger.Formatter.new(),\r\n   filters: [filter_name: {&MyModule.filter/2, []}]\r\n }}\r\n]\r\n```","ref":"Glasgow.html#module-configuration"},{"type":"module","title":"Usage - Glasgow","doc":"Once the handler has been configured and attached, logs can be sent to Loki using the standard `Logger` module.\r\n\r\n```elixir\r\nLogger.info(\"Hello, world!\")\r\n```\r\n\r\nThe library also provides a `send/4` function for sending messages directly and bypass the `Logger`.\r\n\r\n```elixir\r\nGlasgow.send(\"http://localhost:3100\", [{\"label1\",\"value1\"}], \"message\", DateTime.utc_now())\r\n```","ref":"Glasgow.html#module-usage"},{"type":"module","title":"Requirements - Glasgow","doc":"The library requires the `Rust` toolchain because it depends on [`Snappyrex`](https://github.com/c2bw/snappyrex) for Snappy compression.","ref":"Glasgow.html#module-requirements"},{"type":"function","title":"Glasgow.send/4","doc":"Send a single entry to Loki.","ref":"Glasgow.html#send/4"},{"type":"function","title":"Parameters - Glasgow.send/4","doc":"* `base_url` - The base URL of the Loki server.\r\n* `labels` - A list of labels to attach to the log entry.\r\n* `msg` - The log message.\r\n* `time` - The timestamp of the log entry. If not provided, the current time is used.","ref":"Glasgow.html#send/4-parameters"},{"type":"extras","title":"Glasgow","doc":"# Glasgow [![Hex Version](https://img.shields.io/hexpm/v/glasgow.svg)](https://hex.pm/packages/glasgow) [![Hex Docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/glasgow/)\r\n\r\nAn Elixir logger handler for sending logs to [`Grafana Loki`](https://github.com/grafana/loki).","ref":"readme.html"},{"type":"extras","title":"Installation - Glasgow","doc":"The package can be installed by adding `glasgow` to your list of dependencies in `mix.exs`:\r\n\r\n```elixir\r\ndef deps do\r\n  [\r\n    {:glasgow, \"~> 0.1.2\"}\r\n  ]\r\nend\r\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Glasgow","doc":"Example of a basic configuration for `config.exs` or `runtime.exs`:\r\n\r\n```elixir\r\nconfig :my_app, :logger, [\r\n  {:handler, :glasgow, Glasgow,\r\n   %{\r\n     config: %{\r\n       level: :info,\r\n       url: System.get_env(\"URL\", \"http://localhost:3100\"),\r\n       labels: [\r\n         {\"service_name\", \"service_1\"},\r\n         {\"env\", \"env_1\"}\r\n       ]\r\n     },\r\n     formatter: Logger.Formatter.new()\r\n   }}\r\n]\r\n```\r\n\r\nOnce defined, the handler can be explicitly attached with `add_handlers/1`.\r\n\r\nFor example, in your `Application.start/2`:\r\n```elixir\r\n  @impl true\r\n  def start(_type, _args) do\r\n    ...\r\n\r\n    :ok = Logger.add_handlers(:my_app)\r\n\r\n    ...\r\n\r\n    Supervisor.start_link(children, opts)\r\n  end\r\n```\r\n\r\n#### Advanced Configuration\r\nElixir `Logger` handlers can be configured with [`filters`](https://hexdocs.pm/logger/Logger.html#module-filtering) and `metadata` to provide control and context.\r\n\r\n```elixir\r\nconfig :my_app, :logger, [\r\n  {:handler, :glasgow, Glasgow,\r\n   %{\r\n     config: %{\r\n       level: :info,\r\n       url: System.get_env(\"URL\", \"http://localhost:3100\"),\r\n       labels: [\r\n         {\"service_name\", \"service_1\"},\r\n         {\"env\", \"env_1\"}\r\n       ],\r\n       metadata: [:my_metadata_key]\r\n     },\r\n     formatter: Logger.Formatter.new(),\r\n     filters: [filter_name: {&MyModule.filter/2, []}]\r\n   }}\r\n]\r\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Glasgow","doc":"Once the handler has been configured and attached, logs can be sent to Loki using the standard `Logger` module.\r\n\r\n```elixir\r\nLogger.info(\"Hello, world!\")\r\n```\r\n\r\nThe library also provides a `send/4` function for sending messages directly and bypass the `Logger`.\r\n\r\n```elixir\r\nGlasgow.send(\"http://localhost:3100\", [{\"label1\",\"value1\"}], \"message\", DateTime.utc_now())\r\n```","ref":"readme.html#usage"},{"type":"extras","title":"Requirements - Glasgow","doc":"The library requires the `Rust` toolchain because it depends on [`Snappyrex`](https://github.com/c2bw/snappyrex) for Snappy compression.","ref":"readme.html#requirements"},{"type":"extras","title":"LICENSE","doc":"MIT License\r\n\r\nCopyright (c) [2025] [c2bw]\r\n\r\nPermission is hereby granted, free of charge, to any person obtaining a copy\r\nof this software and associated documentation files (the \"Software\"), to deal\r\nin the Software without restriction, including without limitation the rights\r\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\r\ncopies of the Software, and to permit persons to whom the Software is\r\nfurnished to do so, subject to the following conditions:\r\n\r\nThe above copyright notice and this permission notice shall be included in all\r\ncopies or substantial portions of the Software.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\r\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\r\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\r\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\r\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\r\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\r\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}